@@ -1,8 +1,8 @@
-#define VERSION "1.74"
+#define VERSION "1.77"
 
 /*
  *  units, a program for units conversion
- *  Copyright (C) 1996, 1997, 1999, 2000 Free Software Foundation, Inc
+ *  Copyright (C) 1996, 1997, 1999, 2000, 2001 Free Software Foundation, Inc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,9 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *     
- *
  *  This program was written by Adrian Mariano (adrian@cam.cornell.edu)
- *
  */
 
 #include<stdio.h>
@@ -78,13 +76,13 @@ char *errormsg[]={"Successful completion",
 		  "Unit not a root",
 		  "Unknown unit",
 		  "Bad argument",
-		  "Weird function type (bug in program)",
+		  "Weird nonlinear unit type (bug in program)",
 		  "Function argument has wrong dimension",
 		  "Argument of table outside domain",
-		  "Function or table definition has unit error",
+		  "Nonlinear unit definition has unit error",
 		  "No inverse defined",
 		  "Parser memory overflow (recursive function definition?)",
-		  "Argument wrong dimension or bad function definition"
+		  "Argument wrong dimension or bad nonlinear unit definition"
                   };
 
 char *irreducible=0;            /* Name of last irreducible unit */
@@ -347,7 +345,7 @@ readerror(int linenum, const char *filename)
    should give a plain number.  */
 
 void
-readunits(char *userfile)
+readunits() /* char *userfile) */
 {
    struct prefixlist *pfxptr;
    struct unitlist *uptr;
@@ -636,7 +634,7 @@ readunits(char *userfile)
    fclose(unitfile);
    free(line);
    if (!quiet)
-     printf("%d units, %d prefixes, %d functions\n\n", unitcount, prefixcount,
+     printf("%d units, %d prefixes, %d nonlinear units\n\n", unitcount, prefixcount,
 	    funccount);
 }
 
@@ -1805,21 +1803,24 @@ tryallunits(struct unittype *have)
 		&listsize, &maxnamelen, &count);
   for(funcptr=firstfunc;funcptr;funcptr=funcptr->next){
     if (funcptr->table) 
-      addtolist(have, funcptr->name, funcptr->tableunit, "<lookup table>", 
+      addtolist(have, funcptr->name, funcptr->tableunit, "<piecewise linear>", 
 		&list, &listsize, &maxnamelen, &count);
     else
-      addtolist(have, funcptr->name, funcptr->inverse.dimen, "<function>", 
+      addtolist(have, funcptr->name, funcptr->inverse.dimen, "<nonlinear>", 
 		&list, &listsize, &maxnamelen, &count);
   }
   qsort(list, count, sizeof(struct namedef), compnd);
 
   outfile = 0;
-  if (count>screensize())
+  if (count==0)
+    printf("No matching units found.\n");
+  if (count>screensize()){
     outfile = popen(pager, "w");
+  }
   if (!outfile)
     outfile = stdout;
   for(i=0;i<count;i++){
-    fprintf(outfile, "%s",list[i].name);
+    fputs(list[i].name,outfile);
     for(j=strlen(list[i].name);j<=maxnamelen;j++)
       putc(' ',outfile);
     fprintf(outfile, "%s\n",list[i].def);
@@ -2223,7 +2224,7 @@ main(int argc, char **argv)
 
    interactive = processargs(argc, argv, &havestr, &wantstr);
 
-   readunits(userfile);
+   readunits(); /*userfile);*/
 
    if (unitcheck) {
       checkunits(unitcheck==2 || verbose);
